Enum tmp_postgrust::errors::TmpPostgrustError
source · pub enum TmpPostgrustError {
ExecSubprocessFailed {
source: Error,
command: String,
},
SpawnSubprocessFailed(Error),
InitDBFailed(ProcessCapture),
CopyCachedInitDBFailedFileNotFound(Error),
CopyCachedInitDBFailedCouldNotReadFileType(Error),
CopyCachedInitDBFailedCouldNotStripPathPrefix(StripPrefixError),
CreateDBFailed(ProcessCapture),
CreateConfigFailed(Error),
EmptyDataDirectory,
CreateSocketDirFailed(Error),
CreateCacheDirFailed(Error),
UpdatingPermissionsFailed(ProcessCapture),
}Expand description
Error type for possible postgresql errors.
Variants
ExecSubprocessFailed
Fields
Catchall error for when a subprocess fails to run to completion
SpawnSubprocessFailed(Error)
Catchall error for when a subprocess fails to start
InitDBFailed(ProcessCapture)
Error when initdb fails to execute.
CopyCachedInitDBFailedFileNotFound(Error)
Error when a file to be copied is not found.
CopyCachedInitDBFailedCouldNotReadFileType(Error)
Error when the file type cannot be read when copying the cached db.
CopyCachedInitDBFailedCouldNotStripPathPrefix(StripPrefixError)
Error when the source directory filepath cannot be stripped.
CreateDBFailed(ProcessCapture)
Error when createdb fails to execute.
CreateConfigFailed(Error)
Error when postgresql.conf cannot be written.
EmptyDataDirectory
Error when the PGDATA directory is empty.
CreateSocketDirFailed(Error)
Error when the temporary unix socket directory cannot be created.
CreateCacheDirFailed(Error)
Error when the cache directory cannot be created.
UpdatingPermissionsFailed(ProcessCapture)
Error when cp fails for the initialized database.