pub struct ProcessCapture {
pub stdout: String,
pub stderr: String,
}Expand description
UTF-8 captures of stdout and stderr for child processes used by the library.
Capture of stdout from the process
Capture of stderr from the process
Formats the value using the given formatter. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.