Struct tmp_postgrust::TmpPostgrustFactory
source · pub struct TmpPostgrustFactory { /* private fields */ }Expand description
Factory for creating new temporary postgresql processes.
Implementations
sourceimpl TmpPostgrustFactory
impl TmpPostgrustFactory
sourcepub fn try_new() -> TmpPostgrustResult<TmpPostgrustFactory>
pub fn try_new() -> TmpPostgrustResult<TmpPostgrustFactory>
Try to create a new factory by creating temporary directories and the necessary config.
sourcepub fn new_instance(&self) -> TmpPostgrustResult<ProcessGuard>
pub fn new_instance(&self) -> TmpPostgrustResult<ProcessGuard>
Start a new postgresql instance and return a process guard that will ensure it is cleaned up when dropped.