#[non_exhaustive]pub struct TmpPostgrustFactoryConfig {
pub disable_fsync: bool,
pub postgresql_bin_dir: Option<PathBuf>,
}Expand description
Configuration for the TmpPostgrustFactory.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.disable_fsync: boolDisable fsync this will speed up unit tests in exchange for not guaranteeing that files will be written if postgresql crashes.
postgresql_bin_dir: Option<PathBuf>Directory containing the postgres binaries (postgres, initdb,
createdb, createuser). When None, binaries are resolved from
$PATH and common install locations.