Module tmp_postgrust::synchronous
source · Expand description
Methods for Synchronous API
Structs
ProcessGuardrepresents a postgresql process that is running in the background. once the guard is dropped the process will be killed.
Methods for Synchronous API
ProcessGuard represents a postgresql process that is running in the background.
once the guard is dropped the process will be killed.