Enum tmp_postgrust::errors::TmpPostgrustError[][src]

pub enum TmpPostgrustError {
    ExecSubprocessFailed {
        source: Error,
        command: String,
    },
    SpawnSubprocessFailed(Error),
    InitDBFailed(ProcessCapture),
    CopyCachedInitDBFailed(ProcessCapture),
    CopyCachedInitDBFailedFileNotFound(Error),
    CreateDBFailed(ProcessCapture),
    CreateConfigFailed(Error),
    EmptyDataDirectory,
    CreateSocketDirFailed(Error),
    CreateCacheDirFailed(Error),
}
Error type for possible postgresql errors.

Variants

ExecSubprocessFailed

Catchall error for when a subprocess fails to run to completion

Fields of ExecSubprocessFailed

source: Error

Underlying I/O Error.

command: String

Debug formatted string of Command that was attempted.

SpawnSubprocessFailed

Catchall error for when a subprocess fails to start

Tuple Fields of SpawnSubprocessFailed

0: Error
InitDBFailed

Error when initdb fails to execute.

Tuple Fields of InitDBFailed

0: ProcessCapture
CopyCachedInitDBFailed

Error when cp fails for the initialized database.

Tuple Fields of CopyCachedInitDBFailed

0: ProcessCapture
CopyCachedInitDBFailedFileNotFound

Error when a file to be copied is not found.

Tuple Fields of CopyCachedInitDBFailedFileNotFound

0: Error
CreateDBFailed

Error when createdb fails to execute.

Tuple Fields of CreateDBFailed

0: ProcessCapture
CreateConfigFailed

Error when postgresql.conf cannot be written.

Tuple Fields of CreateConfigFailed

0: Error
EmptyDataDirectory

Error when the PGDATA directory is empty.

CreateSocketDirFailed

Error when the temporary unix socket directory cannot be created.

Tuple Fields of CreateSocketDirFailed

0: Error
CreateCacheDirFailed

Error when the cache directory cannot be created.

Tuple Fields of CreateCacheDirFailed

0: Error