Enum tmp_postgrust::errors::TmpPostgrustError [−][src]
pub enum TmpPostgrustError {
ExecSubprocessFailed {
source: Error,
command: String,
},
SpawnSubprocessFailed(Error),
InitDBFailed(ProcessCapture),
CopyCachedInitDBFailed(ProcessCapture),
CopyCachedInitDBFailedFileNotFound(Error),
CreateDBFailed(ProcessCapture),
CreateConfigFailed(Error),
EmptyDataDirectory,
CreateSocketDirFailed(Error),
CreateCacheDirFailed(Error),
}Expand description
Error type for possible postgresql errors.
Variants
Catchall error for when a subprocess fails to run to completion
Fields of ExecSubprocessFailed
Catchall error for when a subprocess fails to start
Tuple Fields of SpawnSubprocessFailed
0: ErrorError when initdb fails to execute.
Tuple Fields of InitDBFailed
Error when cp fails for the initialized database.
Tuple Fields of CopyCachedInitDBFailed
Error when a file to be copied is not found.
Tuple Fields of CopyCachedInitDBFailedFileNotFound
0: ErrorError when createdb fails to execute.
Tuple Fields of CreateDBFailed
Error when postgresql.conf cannot be written.
Tuple Fields of CreateConfigFailed
0: ErrorError when the PGDATA directory is empty.
Error when the temporary unix socket directory cannot be created.
Tuple Fields of CreateSocketDirFailed
0: ErrorError when the cache directory cannot be created.
Tuple Fields of CreateCacheDirFailed
0: Error