pub struct TmpPostgrustFactory { /* fields omitted */ }Expand description
Factory for creating new temporary postgresql processes.
Try to create a new factory by creating temporary directories and the necessary config.
Start a new postgresql instance and return a process guard that will ensure it is cleaned
up when dropped.
Formats the value using the given formatter. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.