Module tmp_postgrust::synchronous[][src]

Methods for Synchronous API

Structs

ProcessGuard represents a postgresql process that is running in the background. once the guard is dropped the process will be killed.