Struct tmp_postgrust::synchronous::ProcessGuard [−][src]
pub struct ProcessGuard {
pub stdout_reader: Option<Lines<BufReader<ChildStdout>>>,
pub stderr_reader: Option<Lines<BufReader<ChildStderr>>>,
pub connection_string: String,
// some fields omitted
}Expand description
ProcessGuard represents a postgresql process that is running in the background. once the guard is dropped the process will be killed.
Fields
stdout_reader: Option<Lines<BufReader<ChildStdout>>>Allows users to read stdout by line for debugging.
stderr_reader: Option<Lines<BufReader<ChildStderr>>>Allows users to read stderr by line for debugging.
connection_string: StringConnection string for connecting to the temporary postgresql instance.